# PyCivil documentation

Is a project that aims to make structural engineers free as possible from 
commercial software. It offers a object-oriented library for Structural 
Engineers.

It can be used every day and extended step by step by engineer.
Typical use is for production, development and testing.

For production, you should use latest version of package writing code
with a nootebook like Jupyter or Marimo.

```
from pycivil.<package-name>.<module-name> import <class-name> as <alias>
```
Typical usage example:
```
from pycivil.EXAStructural.loads import ForcesOnSection as Forces
```

## Packages list

  1. EXAGeometry
  2. EXAGeotechnical
  3. EXAMicroServices
  4. EXAParametric
  5. EXAStructural
  6. EXAStructuralCheckable
  7. EXAStructuralModel
  8. EXAUtils
